# pyEvalData

This is a Python module to evaluate experimental data, e.g. from large-scale
facilities such as synchrotron or FELs.
It is initially meant for reading SPEC data files and providing fundamental
evaluation routines such as binning and uncertainty calculations, as well as
fitting.

Documentation can be found at https://pyevaldata.readthedocs.io